@@ -264,7 +264,7 @@ class MainWindow : public QMainWindow {
 
     void openSelectedNotesInTab();
 
-    void openNoteInTab(const Note &note);
+    void openNoteInTab(const Note &note, bool forceNewTab = false);
 
     void openCurrentNoteInTab();
 
@@ -272,6 +272,11 @@ class MainWindow : public QMainWindow {
 
     void onNavigationWidgetPositionClicked(int position);
 
+    void onNavigationWidgetHeadingRenamed(int position, const QString &oldText,
+                                          const QString &newText);
+
+    void updateBacklinksAfterHeadingRename(const QString &oldHeading, const QString &newHeading);
+
    private slots:
 
     void on_noteTextEdit_textChanged();
@@ -330,6 +335,10 @@ class MainWindow : public QMainWindow {
 
     void on_action_Forward_in_note_history_triggered();
 
+    void on_action_Previous_heading_triggered();
+
+    void on_action_Next_heading_triggered();
+
     void on_action_Shortcuts_triggered();
 
     void on_action_Knowledge_base_triggered();
@@ -376,6 +385,8 @@ class MainWindow : public QMainWindow {
 
     void storeNoteBookmark(int slot = 0);
 
+    void updateNoteBookmarkDisplay();
+
     void on_actionInsert_code_block_triggered();
 
     void on_actionNext_note_triggered();
@@ -1176,6 +1187,7 @@ class MainWindow : public QMainWindow {
     static void handleDockWidgetLocking(QDockWidget *dockWidget);
     void setupNoteRelationScene();
     void updateNoteGraphicsView();
+    bool noteDirectoryWatcherAddPath(const QString &path);
     void addDirectoryToDirectoryWatcher(const QString &path);
     bool nextCloudDeckCheck();
 };
